@@ -6,10 +6,20 @@
 This module provides a function to load pre-compiled stylesheets. To generate your own
 style based on custom color palette clone package from project homepage.
 
-qrainbowstyle.windows module adds frameless windows, which can replace original QMainWindow,
-QDialog and QMessageBox windows. Frameless windows support resizing, moving, snapping to edges.
-You can set global icon and app name for all windows you create in your app. In frameless
-main window it is also possible to set custom QMenu to QToolButton with app icon.
+qrainbowstyle.windows module adds frameless windows and message boxes.
+From version v0.8 module supports native Windows calls.
+Features:
+
+    - Borders snapping
+    - Minimize, restore, close animations
+    - Size grips on borders
+    - Frame shadow
+    - Aero shake
+
+.. image:: https://raw.githubusercontent.com/desty2k/QRainbowStyleSheet/master/images/frameless_window_v3.png
+
+On Linux and Darwin qrainbowstyle will load class with its own implementation of these features.
+Due to a bug in Qt, window minimizing is not supported on MacOS.
 
 First, start importing our module
 
@@ -23,18 +33,18 @@ as shown below
 .. code-block:: python
 
     # PySide2
-    stylesheet = qrainbowstyle.load_stylesheet_pyside2(style='darkblue')
+    stylesheet = qrainbowstyle.load_stylesheet_pyside2(style='oceanic')
     # PyQt5
-    stylesheet = qrainbowstyle.load_stylesheet_pyqt5(style='darkblue')
+    stylesheet = qrainbowstyle.load_stylesheet_pyqt5(style='oceanic')
 
 Alternatively, from environment variables provided by QtPy, Qt.Py
 
 .. code-block:: python
 
     # QtPy
-    stylesheet =  qrainbowstyle.load_stylesheet(style='darkblue')
+    stylesheet =  qrainbowstyle.load_stylesheet(style='oceanic')
     # Qt.Py
-    stylesheet = qrainbowstyle.load_stylesheet(style='darkblue', qt_api=Qt.__binding__)
+    stylesheet = qrainbowstyle.load_stylesheet(style='oceanic', qt_api=Qt.__binding__)
 
 Finally, set your QApplication with it
 
@@ -56,16 +66,16 @@ Next, create instances of frameless window and your master widget with content y
 
     # Create app and load selected stylesheet
     app = QtWidgets.QApplication(sys.argv)
-    app.setStyleSheet(qrainbowstyle.load_stylesheet(style="cyberpunk"))
+    app.setStyleSheet(qrainbowstyle.load_stylesheet(style="oceanic"))
 
     # Package options
-    # qrainbowstyle.align_buttons_left()      # align titlebar buttons to left side
-    # qrainbowstyle.use_darwin_buttons()      # use darwin style buttons
-    qrainbowstyle.set_app_name("My new application")  # set global name for application
-    # qrainbowstyle.set_app_icon("icon.ico")    # set global app icon
+    # qrainbowstyle.alignButtonsLeft()      # align titlebar buttons to left side
+    # qrainbowstyle.useDarwinButtons()      # use darwin style buttons
+    qrainbowstyle.setAppName("My new application")  # set global name for application
+    # qrainbowstyle.setAppIcon("icon.ico")    # set global app icon
 
     # Create frameless mainwindow
-    win = qrainbowstyle.windows.FramelessMainWindow()
+    win = qrainbowstyle.windows.FramelessWindow()
 
     # Create content widget and pass reference to main window
     widget = MasterWidget(win)
@@ -88,9 +98,9 @@ import logging
 import platform
 import qrainbowstyle
 
-__version__ = "0.5.6"
+__version__ = "0.9.5"
 
-_logger = logging.getLogger(__name__)
+_logger = logging.getLogger("qrainbowstyle")
 
 # Folder's path
 REPO_PATH = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
@@ -133,34 +143,29 @@ APP_NAME = None
 APP_ICON_PATH = None
 
 
-def set_app_name(name: str):
-    """Set global app name which will be used in titlebars"""
-    qrainbowstyle.APP_NAME = name
-
-
-def set_app_icon(icon_path: str):
+def setAppIcon(icon_path: str):
     """Set path to app icon which will be used in titlebars"""
     qrainbowstyle.APP_ICON_PATH = icon_path
 
 
-def align_buttons_left():
+def alignButtonsLeft():
     """Align titlebar buttons to left"""
     qrainbowstyle.ALIGN_BUTTONS_LEFT = True
     _logger.info("Buttons will be aligned to left")
 
 
-def use_darwin_buttons():
+def useDarwinButtons():
     """Use darwin styled buttons everywhere in app"""
     qrainbowstyle.USE_DARWIN_BUTTONS = True
     _logger.info("Darwin buttons style has been enabled")
 
 
-def get_available_styles():
+def getAvailableStyles():
     """Get list of available styles"""
-    return [x for x in os.listdir(STYLES_PATH) if x != '__init__.py']
+    return [x for x in os.listdir(STYLES_PATH) if x not in ('__pycache__', '__init__.py')]
 
 
-def get_available_palettes() -> list:
+def getAvailablePalettes() -> list:
     """Get list of available palettes"""
     import qrainbowstyle.palette as source
     palettes = []
@@ -170,10 +175,10 @@ def get_available_palettes() -> list:
     return palettes
 
 
-def get_current_palette():
+def getCurrentPalette():
     """Returns loaded palette"""
     try:
-        from style_rc import palette
+        from style_rc import palette  # noqa
         return palette
     except ModuleNotFoundError:
         raise ModuleNotFoundError("Cannot find current palette. Did you load style sheet?")
@@ -181,7 +186,7 @@ def get_current_palette():
 
 def rainbowize(text: str) -> str:
     """Replaces colors names to hashes in text"""
-    color_dict = get_current_palette().to_dict()
+    color_dict = getCurrentPalette().to_dict()
     for color in color_dict:
         text = text.replace(color, str(color_dict[color]))
     return text
@@ -197,7 +202,7 @@ def _apply_os_patches(palette):
     os_fix = ""
 
     if platform.system().lower() == 'darwin':
-        # See issue #12
+        # See issue #12, #267
         os_fix = '''
         QDockWidget::title
         {{
@@ -205,7 +210,10 @@ def _apply_os_patches(palette):
             text-align: center;
             height: 12px;
         }}
-        '''.format(color=palette.COLOR_BACKGROUND_NORMAL)
+        QTabBar::close-button {{
+            padding: 2px;
+        }}
+        '''.format(color=palette.COLOR_BACKGROUND_4)
 
     # Only open the QSS file if any patch is needed
     if os_fix:
@@ -229,15 +237,29 @@ def _apply_binding_patches():
     return binding_fix
 
 
-def _apply_version_patches():
+def _apply_version_patches(qt_version):
     """
     Apply version-only specific stylesheet patches for the same binding.
 
+    Args:
+        qt_version (str): Qt string version.
+
     Returns:
         str: stylesheet string (css).
     """
     version_fix = ""
 
+    major, minor, patch = qt_version.split('.')
+    major, minor, patch = int(major), int(minor), int(patch)
+
+    if major == 5 and minor >= 14:
+        # See issue #214
+        version_fix = '''
+        QMenu::item {
+            padding: 4px 24px 4px 6px;
+        }
+        '''
+
     if version_fix:
         _logger.info("Found version patches to be applied.")
 
@@ -253,7 +275,7 @@ def _apply_application_patches(palette, QCoreApplication, QPalette, QColor):
     that moment for setting reasons.
     """
     # See issue #139
-    color = palette.COLOR_SELECTION_LIGHT
+    color = palette.COLOR_ACCENT_3
     qcolor = QColor(color)
 
     # Todo: check if it is qcoreapplication indeed
@@ -262,9 +284,9 @@ def _apply_application_patches(palette, QCoreApplication, QPalette, QColor):
     _logger.info("Found application patches to be applied.")
 
     if app:
-        _palette = app.palette()
-        _palette.setColor(QPalette.Normal, QPalette.Link, qcolor)
-        app.setPalette(_palette)
+        app_palette = app.palette()
+        app_palette.setColor(QPalette.Normal, QPalette.Link, qcolor)
+        app.setPalette(app_palette)
     else:
         _logger.warning("No QCoreApplication instance found. "
                         "Application patches not applied. "
@@ -301,14 +323,15 @@ def _load_stylesheet(qt_api='', style=''):
     # Import is made after setting QT_API
     from qtpy.QtCore import QCoreApplication, QFile, QTextStream
     from qtpy.QtGui import QColor, QPalette
+    from qtpy import QT_VERSION
 
     # Search for style in styles directory
     style_dir = None
 
-    available_styles = [x for x in os.listdir(STYLES_PATH) if x != '__init__.py']
+    available_styles = getAvailableStyles()
     _logger.debug(f"Available styles: {available_styles}")
     for stl in available_styles:
-        if style.lower() in stl.lower():
+        if style.lower() == stl.lower():
             style_dir = stl
             break
 
@@ -321,7 +344,7 @@ def _load_stylesheet(qt_api='', style=''):
         _logger.info("Found already imported style in sys.modules")
 
         # use qCleanupResources to remove all resource files
-        global style_rc
+        global style_rc  # noqa
         style_rc.qCleanupResources()
 
         # remove imported modules
@@ -330,23 +353,30 @@ def _load_stylesheet(qt_api='', style=''):
             del style_rc
 
         # remove path to previously imported style from sys.path
-        for stylepath in [path for path in sys.path if any(style for style in get_available_styles() if style in path)]:
+        for stylepath in [path for path in sys.path if any(style for style in getAvailableStyles() if style in path)]:
             sys.path.remove(stylepath)
         _logger.debug("Removed all imported styles")
 
     try:
         _logger.debug("Loading style from directory: " + style_dir)
-
+        old_working_dir = os.getcwd()
         # set style directory
         package_dir = os.path.join(STYLES_PATH, style_dir)
         os.chdir(package_dir)
 
         # append directory to sys.path and import style_rc
         sys.path.append(package_dir)
-        import style_rc
+        try:
+            import style_rc  # noqa
+            # get palette
+            palette = style_rc.palette
+
+        except ModuleNotFoundError:
+            raise ModuleNotFoundError("Failed to import style_rc from directory: {}".format(package_dir))
+
+        finally:
+            os.chdir(old_working_dir)
 
-        # get palette
-        palette = style_rc.palette
     except FileExistsError:
         raise FileNotFoundError("Missing style_rc.py file")
 
@@ -383,7 +413,7 @@ def _load_stylesheet(qt_api='', style=''):
     stylesheet += _apply_binding_patches()
 
     # 3. Apply binding version specific patches
-    stylesheet += _apply_version_patches()
+    stylesheet += _apply_version_patches(QT_VERSION)
 
     # 4. Apply palette fix. See issue #139
     _apply_application_patches(palette, QCoreApplication, QPalette, QColor)
@@ -391,7 +421,7 @@ def _load_stylesheet(qt_api='', style=''):
     return stylesheet
 
 
-def load_stylesheet(qt_api="", style='darkblue'):
+def load_stylesheet(qt_api="", style='qdarkstyle3'):
     """
     Load the stylesheet. Takes care of importing the rc module.
 
